# frozen_string_literal: true

require 'qlogger_client/version'
require 'qlogger_client/configuration'
require 'rest_client'
require 'json'
require 'uri'


module QloggerClient

  def self.auth(login, password)
    url = "#{configuration.url}/sessions"
    credentials = {
      "admin_user_session": {
        "login": login,
        "password": password
      }
    }
    request = RestClient.post url, credentials, headers
    if request.code == 200
      configuration.token = JSON.parse(request.body)['token']
    end
    request.code
  end

  def self.list(search_params={})
    url = "#{configuration.url}/logs?#{URI.encode_www_form(search_params)}"
    RestClient.get url, headers
  end

  def self.retrieve(id)
    url = "#{configuration.url}/logs/#{id}"
    RestClient.get url, headers
  end

  def self.log(log_params)
    url = "#{configuration.url}/logs"
    RestClient.post url, log_params, headers
  end

  def self.headers
    { "Authorization": configuration.token }
  end

  class << self
    attr_accessor :configuration

    def configuration
      @configuration ||= Configuration.new
    end

    def configure
      yield(configuration)
    end
  end
end
